@@ -3,7 +3,6 @@
 from __future__ import annotations
 
 from pathlib import Path
-from typing import Callable
 
 import click
 
@@ -18,10 +17,6 @@ def _echo(_: Path, code: str) -> None:
     click.echo(code)
 
 
-def _make_callback(overwrite: bool) -> Callable[[Path, str], None]:
-    return _overwrite if overwrite else _echo
-
-
 @click.group(
     help="Rewrite protoc or buf-generated imports for use by the protoletariat.",
     context_settings=dict(max_content_width=140),
@@ -55,8 +50,8 @@ def _make_callback(overwrite: bool) -> Callable[[Path, str], None]:
     "--module-suffixes",
     type=str,
     multiple=True,
-    default=["_pb2.py", "_pb2_grpc.py"],
-    help="Suffixes of Python modules to process",
+    default=["_pb2.py", "_pb2.pyi", "_pb2_grpc.py", "_pb2_grpc.pyi"],
+    help="Suffixes of Python/mypy modules to process",
     show_default=True,
 )
 @click.pass_context
@@ -72,7 +67,7 @@ def main(
         dict(
             python_out=python_out,
             create_package=create_package,
-            overwrite_callback=_make_callback(in_place),
+            overwrite_callback=_overwrite if in_place else _echo,
             module_suffixes=module_suffixes,
         )
     )
